# pybirdsreynolds

This project is an interactive simulation of the Reynolds Boids model, implemented in Python with Tkinter. It allows you to visualize and experiment with the collective behavior of a flock of virtual birds by adjusting parameters such as cohesion, alignment, separation, speed, and neighborhood radius in real time. The interface also provides several controls (pause, reset, new generation, FPS display, etc.) to easily explore the dynamics of the system.

<img width="1451" height="666" alt="image" src="https://github.com/user-attachments/assets/a5a50a62-989c-457c-a0c4-a86240210f7b" />

# Installation/Upgrade 

## Prerequisites

- Install Python 3 for your system
- Install pipx for your system

## Installation 

``pipx install pybirdsreynolds``

## Upgrade 

``pipx upgrade pybirdsreynolds``

# Use

```pybirdsreynolds```

- If you obtain error about tk, install python3-tk
``` 
sudo apt install python3-tk #for ubuntu
sudo pacman -S tk #for arch
brew install python-tk #for mac
```

# Documentation and options

```pybirdsreynolds --help```
